/* 	libchenabler - Application of the call history service
 *
 *	Authors: JIANG Dan <dan.jiang@orange-ftgroup.com> 
 *	
 *	This software and associated documentation files (the "Software") 
 *	are copyright (C) 2005 LiPS Linux Phone Standards Forum [FranceTelecom] 
 *	All Rights Reserved. 
 *
 *	A copyright license is hereby granted for redistribution and use of 
 *	the Software in source and binary forms, with or without modification, 
 *	provided that the following conditions are met: 
 *	- Redistributions of source code must retain the above copyright notice, 
 *	this copyright license and the following disclaimer. 
 * - Redistributions in binary form must reproduce the above copyright 
 *	notice, this copyright license and the following disclaimer in the 
 *	documentation and/or other materials provided with the distribution. 
 *	- Neither the name of LiPS  nor the names of its Members may be used 
 *	to endorse or promote products derived from the Software without 
 *	specific prior written permission. 
 *
 *	A patent license for any Necessary Claims owned by Members of LiPS Forum 
 *	to make, have made, use, import, offer to sell, lease and sell or otherwise 
 *	distribute any implementation compliant with the any specification adopted 
 *	by the LiPS Forumcan be obtained from the respective Members on reasonable 
 *	and non-discriminatory terms and conditions and under reciprocity, as 
 *	regulated in more detail in the Internal Policy of the LiPS Forum. 
 *
 *	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER, ITS MEMBERS AND CONTRIBUTORS 
 *	"AS IS", AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 *	THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
 *	AND NON-INFRINGEMENT ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER, 
 *	ITS MEMBERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *	SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 *	PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 *	OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 *	WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *	ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 *	POSSIBILITY OF SUCH DAMAGE. 
 */


#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdio.h>
#include <stdlib.h>
#include "vochistorylistview.h"
#include <vochtype.h>

typedef enum
{
  COL_TYPENAME,
  COL_TYPEID
} Collist;


static struct
{
  GtkWidget *mainwindow;
  GtkWidget *treeview;
  GtkWidget *scroll_window;
  GtkListStore *liststore;
} self;


static void
main_listview_row_activated (GtkTreeView *treeview, GtkTreePath *path,
                             GtkTreeViewColumn *col, gpointer user_data)
{
  GtkTreeModel *model = NULL;
  GtkTreeIter iter;

  model = gtk_tree_view_get_model (treeview);
  if (gtk_tree_model_get_iter (model, &iter, path))
  {
    voch_call_type_t type;

    gtk_tree_model_get (model, &iter, COL_TYPEID, &type, -1);

    show_history_listview (type);

//     g_free(type);
  }

  return;
}

gboolean
main_listview_focus_in_event_cb (GtkWidget *widget, GdkEventFocus *event,
                                 gpointer user_data)
{
  gtk_widget_grab_focus (self.treeview);
  return FALSE;
}

gboolean
main_listview_load_data (GtkListStore *liststore)
{
  GtkTreeIter iter;

  gtk_list_store_append (GTK_TREE_MODEL (liststore), &iter);
  gtk_list_store_set (GTK_TREE_MODEL (liststore), &iter,
                      COL_TYPENAME, "Outgoing Call", COL_TYPEID, OUTGOING, -1);
  gtk_list_store_append (GTK_TREE_MODEL (liststore), &iter);
  gtk_list_store_set (GTK_TREE_MODEL (liststore), &iter,
                      COL_TYPENAME, "Incoming Call",
                      COL_TYPEID, INCOMING_ANSWER, -1);
  gtk_list_store_append (GTK_TREE_MODEL (liststore), &iter);
  gtk_list_store_set (GTK_TREE_MODEL (liststore), &iter,
                      COL_TYPENAME, "Missed Call",
                      COL_TYPEID, INCOMING_MISSED, -1);
  gtk_list_store_append (GTK_TREE_MODEL (liststore), &iter);
  gtk_list_store_set (GTK_TREE_MODEL (liststore), &iter,
                      COL_TYPENAME, "Duration", COL_TYPEID, 6, -1);
  return TRUE;
}

static void
main_listview_softkey_activated_cb (GtkWidget *window, gint nr)
{
  if (nr == 1)
  {
    gtk_main_quit ();
  }
  if (nr == 0)
  {
    GtkTreePath *path = NULL;
    GtkTreeViewColumn *col = NULL;

    gtk_tree_view_get_cursor (self.treeview, &path, &col);
    gtk_tree_view_row_activated (self.treeview, path, col);
  }
}

GtkWidget *
create_typechose_window ()
{
  GtkWidget *mainwindow;
  GtkWidget *titlebar;
  GtkTreeViewColumn *col;
  GtkCellRenderer *renderer;
  GtkWidget *vbox = NULL;
  PangoFontDescription *font_desc;
  GtkWidget *frame1, *frame2;
  static GdkColor list_bg = { 0, 57015, 61602, 62879 };
  mainwindow = gpe_skwindow_new ();
  gtk_widget_modify_bg (mainwindow, GTK_STATE_NORMAL, &list_bg);
  titlebar = gtk_label_new ("Call History");
  font_desc = pango_font_description_from_string ("Sans plaint 15");
  gtk_widget_modify_font (titlebar, font_desc);
  pango_font_description_free (font_desc);
  gtk_widget_set_size_request (titlebar, -1, 40);

  self.scroll_window = gtk_scrolled_window_new (NULL, NULL);

  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (self.scroll_window),
                                  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW
                                       (self.scroll_window),
                                       GTK_SHADOW_ETCHED_IN);

  self.liststore = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);

  self.treeview = gtk_tree_view_new ();

  gtk_tree_view_set_hadjustment (GTK_TREE_VIEW (self.treeview),
                                 gtk_scrolled_window_get_hadjustment
                                 (GTK_SCROLLED_WINDOW (self.scroll_window)));

  col = gtk_tree_view_column_new ();
  gtk_tree_view_column_set_title (col, "TypeName");
  gtk_tree_view_append_column (GTK_TREE_VIEW (self.treeview), col);

  renderer = gtk_cell_renderer_text_new ();
  gtk_cell_renderer_set_fixed_size (renderer, 150, 54);
  g_object_set (G_OBJECT (renderer), "font", "Sans plaint 15", NULL);

  gtk_widget_modify_bg (self.treeview, GTK_STATE_ACTIVE, &list_bg);
  g_object_set (G_OBJECT (renderer), "ypad", 12, NULL);
  g_object_set (G_OBJECT (renderer), "xalign", 0.5, NULL);
  gtk_tree_view_column_pack_start (col, renderer, TRUE);
  gtk_tree_view_column_add_attribute (col, renderer, "text", COL_TYPENAME);

  gtk_tree_view_set_model (GTK_TREE_VIEW (self.treeview),
                           GTK_TREE_MODEL (self.liststore));
  gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (self.treeview), FALSE);

  g_signal_connect (G_OBJECT (self.treeview), "row-activated",
                    G_CALLBACK (main_listview_row_activated),
                    (gpointer) mainwindow);



  gtk_container_add (GTK_CONTAINER (self.scroll_window), self.treeview);

  vbox = gtk_vbox_new (FALSE, 0);

  frame1 = gtk_frame_new (NULL);
  gtk_container_add (GTK_CONTAINER (frame1), titlebar);
  gtk_box_pack_start (GTK_BOX (vbox), frame1, FALSE, FALSE, 0);

  gtk_box_pack_start (GTK_BOX (vbox), self.scroll_window, TRUE, TRUE, 0);

  gtk_container_add (GTK_CONTAINER (mainwindow), vbox);

  g_signal_connect (G_OBJECT (mainwindow), "focus-in-event",
                    G_CALLBACK (main_listview_focus_in_event_cb), NULL);
  main_listview_load_data (self.liststore);
  gpe_skwindow_set_softkey_label (GPE_SKWINDOW (mainwindow), 0, "Ok");
  gpe_skwindow_set_softkey_label (GPE_SKWINDOW (mainwindow), 1, "Back");
  g_signal_connect (G_OBJECT (mainwindow), "softkey_activated",
                    G_CALLBACK (main_listview_softkey_activated_cb), NULL);


  return mainwindow;

}

