/* 	libchenabler - Application of the call history service
 *
 *	Authors: JIANG Dan <dan.jiang@orange-ftgroup.com> 
 *	
 *	This software and associated documentation files (the "Software") 
 *	are copyright (C) 2005 LiPS Linux Phone Standards Forum [FranceTelecom] 
 *	All Rights Reserved. 
 *
 *	A copyright license is hereby granted for redistribution and use of 
 *	the Software in source and binary forms, with or without modification, 
 *	provided that the following conditions are met: 
 *	- Redistributions of source code must retain the above copyright notice, 
 *	this copyright license and the following disclaimer. 
 * - Redistributions in binary form must reproduce the above copyright 
 *	notice, this copyright license and the following disclaimer in the 
 *	documentation and/or other materials provided with the distribution. 
 *	- Neither the name of LiPS  nor the names of its Members may be used 
 *	to endorse or promote products derived from the Software without 
 *	specific prior written permission. 
 *
 *	A patent license for any Necessary Claims owned by Members of LiPS Forum 
 *	to make, have made, use, import, offer to sell, lease and sell or otherwise 
 *	distribute any implementation compliant with the any specification adopted 
 *	by the LiPS Forumcan be obtained from the respective Members on reasonable 
 *	and non-discriminatory terms and conditions and under reciprocity, as 
 *	regulated in more detail in the Internal Policy of the LiPS Forum. 
 *
 *	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER, ITS MEMBERS AND CONTRIBUTORS 
 *	"AS IS", AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 *	THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
 *	AND NON-INFRINGEMENT ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER, 
 *	ITS MEMBERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *	SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 *	PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 *	OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 *	WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *	ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 *	POSSIBILITY OF SUCH DAMAGE. 
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdio.h>
#include <stdlib.h>

#include <vochtype.h>
#include <callhistory.h>
#include "vochistorylistview.h"
#include "mainlistview.h"
#include "voch-iac.h"
enum
{
  SK_LEFT = 0,
  SK_RIGHT = 1,
  SK_MAX = 2
};
enum
{
  KEY_SEND = 65474
};
GtkWidget *historylistview;
voch_sid_t sid;

static void
listview_call_cb ()
{
//vochistory_listview_load_data(VOCHISTORY_LISTVIEW(historylistview),sid,OUTGOING);
  char *num;

  getcurrowinfo (VOCHISTORY_LISTVIEW (historylistview), &num, NULL, NULL);
  char *num_dup = g_strdup (num);

  call_iac (num_dup);
  printf ("\n%s\n", num_dup);
  g_free (num_dup);
}
static void
listview_send_cb ()
{

//   vochistory_listview_load_data(VOCHISTORY_LISTVIEW(historylistview),sid,INCOMING_MISSED);
}
static void
listview_delete_cb ()
{
  vochistory_listview_delete_current (VOCHISTORY_LISTVIEW (historylistview),
                                      sid);
}
static void
history_listview_softkey_activated_cb (GtkWidget *window, gint nr)
{
  if (nr == 1)
  {
    gtk_window_iconify (GTK_WINDOW (window));
  }
}
static gboolean
window_key_press_event (GtkWidget *widget, GdkEventKey *k, gpointer data)
{
  switch (k->keyval)
  {
    case KEY_SEND:
      listview_call_cb ();
      return TRUE;
    default:
      break;
  }
  return FALSE;
}

static const gchar *menu_desc = " \
    <ui>\
        <popup  action=\"listview_menu\">\
            <menuitem name=\"call\"         action=\"Call\"/>\
            <menuitem name=\"send_sms\"     action=\"Send_sms\"/>\
            <menuitem name=\"delete\"       action=\"Delete\"/>\
        </popup>\
    </ui>\
";
static const GtkActionEntry mainview_actions[] = {
  {"Call", NULL, "Call", "", "none", listview_call_cb},
  {"Send_sms", NULL, "Send Sms", "", "none", listview_send_cb},
  {"Delete", NULL, "Delete", "", "none", listview_delete_cb},
  {"PopupLeft", NULL, "Popup", "", "none", NULL},
};
static void
mainview_init_menu (VocHistoryListView *window)
{
//   GpeSKWindow *window = GPE_SKWINDOW(sk_window->window);

  GtkActionGroup *action_group = NULL;
  GtkUIManager *ui_manager = NULL;
  GtkWidget *menu_left = NULL;
  GError *error = NULL;

  if (window == NULL)
  {
    g_print ("%s(): null sk_window\n", __FUNCTION__);
    return;
  }

  action_group = gtk_action_group_new ("MainViewActions");
  ui_manager = gtk_ui_manager_new ();

  gtk_action_group_add_actions (action_group, mainview_actions,
                                G_N_ELEMENTS (mainview_actions), NULL);
  gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
  if (!gtk_ui_manager_add_ui_from_string (ui_manager, menu_desc, -1, &error))
  {
    g_print ("%s(): failed to parse menu data: %s\n", __FUNCTION__,
             error->message);
    g_error_free (error);
    return;
  }

  menu_left = gtk_ui_manager_get_widget (ui_manager, "/listview_menu");

  gpe_skwindow_set_softkey_menu (GPE_SKWINDOW (window), SK_LEFT, menu_left);
  gpe_skwindow_set_softkey_menu (GPE_SKWINDOW (window), SK_RIGHT, NULL);

  gpe_skwindow_set_softkey_label (GPE_SKWINDOW (window), SK_LEFT, "Options");
  gpe_skwindow_set_softkey_label (GPE_SKWINDOW (window), SK_RIGHT, "Back");

  g_signal_connect (G_OBJECT (window), "softkey_activated",
                    G_CALLBACK (history_listview_softkey_activated_cb), NULL);

  return;
}

void
show_history_listview (voch_call_type_t type)
{
  if (type == 6)
    return;
  if (historylistview)
  {
    vochistory_listview_load_data (VOCHISTORY_LISTVIEW (historylistview), sid,
                                   type);
    gtk_window_deiconify (GTK_WINDOW (historylistview));
    gtk_window_present (GTK_WINDOW (historylistview));
  }
  else
  {
    historylistview = vochistory_listview_new ();
    mainview_init_menu (VOCHISTORY_LISTVIEW (historylistview));
    g_signal_connect (G_OBJECT (historylistview), "key_press_event",
                      G_CALLBACK (window_key_press_event), NULL);
    vochistory_listview_load_data (VOCHISTORY_LISTVIEW (historylistview), sid,
                                   type);
    gtk_widget_show_all (historylistview);
  }

}
int
main (int argc, char *argv[])
{
  GtkWidget *mainwindow;
  GtkWidget *listframe;
  GtkTreeIter iter;

  voch_init ();
  voch_connect (0, &sid);

  gpe_application_init (&argc, &argv);
  mainwindow = create_typechose_window ();
  gtk_widget_show_all (mainwindow);

  gtk_main ();
  return EXIT_SUCCESS;
}


