/* 	libchenabler - Application of the call history service
 *
 *	Authors: JIANG Dan <dan.jiang@orange-ftgroup.com> 
 *	
 *	This software and associated documentation files (the "Software") 
 *	are copyright (C) 2005 LiPS Linux Phone Standards Forum [FranceTelecom] 
 *	All Rights Reserved. 
 *
 *	A copyright license is hereby granted for redistribution and use of 
 *	the Software in source and binary forms, with or without modification, 
 *	provided that the following conditions are met: 
 *	- Redistributions of source code must retain the above copyright notice, 
 *	this copyright license and the following disclaimer. 
 * - Redistributions in binary form must reproduce the above copyright 
 *	notice, this copyright license and the following disclaimer in the 
 *	documentation and/or other materials provided with the distribution. 
 *	- Neither the name of LiPS  nor the names of its Members may be used 
 *	to endorse or promote products derived from the Software without 
 *	specific prior written permission. 
 *
 *	A patent license for any Necessary Claims owned by Members of LiPS Forum 
 *	to make, have made, use, import, offer to sell, lease and sell or otherwise 
 *	distribute any implementation compliant with the any specification adopted 
 *	by the LiPS Forumcan be obtained from the respective Members on reasonable 
 *	and non-discriminatory terms and conditions and under reciprocity, as 
 *	regulated in more detail in the Internal Policy of the LiPS Forum. 
 *
 *	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER, ITS MEMBERS AND CONTRIBUTORS 
 *	"AS IS", AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 *	THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
 *	AND NON-INFRINGEMENT ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER, 
 *	ITS MEMBERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *	SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 *	PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 *	OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 *	WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *	ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 *	POSSIBILITY OF SUCH DAMAGE. 
 */


#include <libintl.h>
#include <ctype.h>

#include <gtk/gtk.h>
#include <gdk/gdkkeysyms.h>

#include "vochistorylistview.h"
#include <callhistory.h>
#include <vochcallhistory.h>
#include <vochtype.h>
#define _(x) gettext(x)

static void vochistory_listview_class_init (VocHistoryListViewClass *klass);
static void vochistory_listview_init (VocHistoryListView *window);

GType
vochistory_listview_get_type (void)
{
  static GType listview_type = 0;

  if (!listview_type)
  {
    static const GTypeInfo listview_info = {
      sizeof (VocHistoryListViewClass),
      NULL,                     /* base_init */
      NULL,                     /* base_finalize */
      (GClassInitFunc) vochistory_listview_class_init,
      NULL,                     /* class_finalize */
      NULL,                     /* class_data */
      sizeof (VocHistoryListView),
      0,                        /* n_preallocs */
      (GInstanceInitFunc) vochistory_listview_init,
    };

    listview_type =
      g_type_register_static (GPE_TYPE_SKWINDOW, "VocHistoryListView",
                              &listview_info, 0);
  }

  return listview_type;
}

static void
vochistory_listview_class_init (VocHistoryListViewClass *klass)
{
  return;
}

static void
vochistory_listview_row_activated (GtkTreeView *treeview, GtkTreePath *path,
                                   GtkTreeViewColumn *col, gpointer user_data)
{
  VocHistoryListView *view = (VocHistoryListView *) user_data;
  GtkTreeModel *model = NULL;
  GtkTreeIter iter;

  model = gtk_tree_view_get_model (treeview);
  if (gtk_tree_model_get_iter (model, &iter, path))
  {
    gchar *cid = NULL;

    gtk_tree_model_get (model, &iter, COL_CID, &cid, -1);

    if (view->row_activated_cb)
    {
      view->row_activated_cb (view, cid);
    }

    g_free (cid);
  }

  return;
}


void
getcurrowinfo (VocHistoryListView *view, char *num, time_t *start_date,
               time_t *duration)
{
  if (view)
  {
    GtkTreeView *treeview = GTK_TREE_VIEW (view->treeview);
    GtkTreePath *path = NULL;
    GtkTreeViewColumn *col = NULL;
    GtkTreeModel *model = NULL;
    GtkTreeIter iter;

    model = gtk_tree_view_get_model (treeview);
    gtk_tree_view_get_cursor (treeview, &path, &col);
    if (model && path)
    {
      gtk_tree_model_get_iter (model, &iter, path);
      if (num != NULL)
        gtk_tree_model_get (model, &iter, COL_PNUM, num, -1);
      if (start_date != NULL)
        gtk_tree_model_get (model, &iter, COL_DURATION, start_date, -1);
      if (duration != NULL)
        gtk_tree_model_get (model, &iter, COL_DATE, duration, -1);
    }
  }
}

gboolean
vochistory_listview_delete_current (VocHistoryListView *view, voch_sid_t sid)
{
  gchar *cid_str = NULL;
  voch_cid_t cid;

  if (view)
  {
    GtkTreeView *treeview = GTK_TREE_VIEW (view->treeview);
    GtkTreePath *path = NULL;
    GtkTreeViewColumn *col = NULL;
    GtkTreeModel *model = NULL;
    GtkTreeIter iter;

    model = gtk_tree_view_get_model (treeview);
    gtk_tree_view_get_cursor (treeview, &path, &col);

    if (model && path)
    {
      gtk_tree_model_get_iter (model, &iter, path);
      gtk_tree_model_get (model, &iter, COL_CID, &cid_str, -1);
    }

    gtk_tree_path_free (path);
    uuid_parse (cid_str, cid);
    g_free (cid_str);
    voch_rm_history (sid, &cid);
    g_print ("\nthe delete cid is :%s", misc_binary_to_str (cid, 16));
    gtk_list_store_remove (model, &iter);
  }
  return TRUE;

}

gboolean
vochistory_listview_load_data (VocHistoryListView *view, voch_sid_t sid,
                               voch_call_type_t datatype)
{
  switch (datatype)
  {
    case INCOMING_MISSED:
      gtk_label_set_text (GTK_LABEL (view->titlebar), "Missed Call");
      break;
    case INCOMING_ANSWER:
      gtk_label_set_text (GTK_LABEL (view->titlebar), "Icoming Call");
      break;
    case OUTGOING:
      gtk_label_set_text (GTK_LABEL (view->titlebar), "Outgoing Call");
      break;
    default:
      break;
  }
  voch_callhistory_t **history;

  history = voch_get_historys_by_type (sid, datatype);
  if (!history)
    return FALSE;
  gtk_list_store_clear (view->liststore);
  time_t *date;
  struct tm time;
  GtkTreeIter iter;
  int pos = 1;

  while (*history)
  {
    memset (&time, 0x00, sizeof (time));
    voch_callhistory_get_date (*history, &date);
    localtime_r (&(*date), &time);
    gchar *pnum, *cid_str;
    voch_cid_t *cid;

    voch_callhistory_get_phonenumber (*history, &pnum);
    voch_callhistory_get_cid (*history, &cid);
    cid_str = g_new0 (gchar, 36 + 1);
    uuid_unparse (cid, cid_str);
    gchar *timestamp = g_strdup_printf ("%02d/%02d/%d\n%02d:%02d:%02d",
                                        time.tm_mon + 1,
                                        time.tm_mday,
                                        time.tm_year + 1900,
                                        time.tm_hour,
                                        time.tm_min,
                                        time.tm_sec);
    gchar *row_num = g_strdup_printf ("%d", pos++);

    gtk_list_store_append (GTK_TREE_MODEL (view->liststore), &iter);
    gtk_list_store_set (GTK_TREE_MODEL (view->liststore), &iter,
                        COL_CID, cid_str,
                        COL_PNUM, pnum,
                        COL_DATE, timestamp, COL_SORT_BASE, *date, -1);
    g_free (timestamp);
    g_free (row_num);
    g_free (cid_str);
    voch_callhistory_free (*history);
    history++;
  }
  return TRUE;
}

gboolean
vochistory_listview_focus_in_event_cb (GtkWidget *widget,
                                       GdkEventFocus *event,
                                       gpointer user_data)
{
  VocHistoryListView *view = (VocHistoryListView *) widget;

  gtk_widget_grab_focus (view->treeview);
//      vochistory_listview_update(view);

  return FALSE;
}


static void
vochistory_listview_init (VocHistoryListView *view)
{
  GtkTreeViewColumn *col;
  GtkCellRenderer *renderer;
  GtkWidget *vbox = NULL;
  PangoFontDescription *font_desc;
  GtkWidget *frame1, *frame2;
  static GdkColor list_bg = { 0, 57015, 61602, 62879 };

  gtk_widget_modify_bg (view, GTK_STATE_NORMAL, &list_bg);
  view->titlebar = gtk_label_new ("");
  font_desc = pango_font_description_from_string ("Sans plaint 15");
  gtk_widget_modify_font (view->titlebar, font_desc);
  pango_font_description_free (font_desc);

  gtk_widget_set_size_request (view->titlebar, -1, 40);

  view->scroll_window = gtk_scrolled_window_new (NULL, NULL);

  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (view->scroll_window),
                                  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW
                                       (view->scroll_window),
                                       GTK_SHADOW_ETCHED_IN);

  view->liststore = gtk_list_store_new (NUM_COLS,
                                        G_TYPE_STRING,
                                        G_TYPE_STRING,
                                        G_TYPE_STRING,
                                        G_TYPE_STRING,
                                        G_TYPE_STRING,
                                        G_TYPE_STRING, G_TYPE_INT);
  gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (view->liststore),
                                        COL_SORT_BASE, GTK_SORT_DESCENDING);

  view->treeview = gtk_tree_view_new ();
  gtk_tree_view_set_hadjustment (GTK_TREE_VIEW (view->treeview),
                                 gtk_scrolled_window_get_hadjustment
                                 (GTK_SCROLLED_WINDOW (view->scroll_window)));

  col = gtk_tree_view_column_new ();
  gtk_tree_view_column_set_title (col, "Name");
  gtk_tree_view_append_column (GTK_TREE_VIEW (view->treeview), col);

  renderer = gtk_cell_renderer_text_new ();
  gtk_cell_renderer_set_fixed_size (renderer, 130, 60);
  g_object_set (G_OBJECT (renderer), "font", "Sans plaint 12", NULL);
  g_object_set (G_OBJECT (renderer), "ypad", 5, NULL);
  g_object_set (G_OBJECT (renderer), "xpad", 10, NULL);
  gtk_tree_view_column_pack_start (col, renderer, TRUE);
  gtk_tree_view_column_add_attribute (col, renderer, "text", COL_PNUM);

  /* column pic */
  col = gtk_tree_view_column_new ();
  gtk_tree_view_column_set_title (col, "date");
  gtk_tree_view_append_column (GTK_TREE_VIEW (view->treeview), col);

  renderer = gtk_cell_renderer_text_new ();
  gtk_cell_renderer_set_fixed_size (renderer, 130, 60);
  g_object_set (G_OBJECT (renderer), "font", "Sans plaint 12", NULL);
  g_object_set (G_OBJECT (renderer), "ypad", 5, NULL);
  gtk_tree_view_column_pack_start (col, renderer, TRUE);
  gtk_tree_view_column_add_attribute (col, renderer, "text", COL_DATE);

  gtk_tree_view_set_model (GTK_TREE_VIEW (view->treeview),
                           GTK_TREE_MODEL (view->liststore));
  gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (view->treeview), FALSE);
  g_signal_connect (G_OBJECT (view->treeview), "row-activated",
                    G_CALLBACK (vochistory_listview_row_activated),
                    (gpointer) view);

  gtk_container_add (GTK_CONTAINER (view->scroll_window), view->treeview);

  vbox = gtk_vbox_new (FALSE, 0);
  frame1 = gtk_frame_new (NULL);
  gtk_container_add (GTK_CONTAINER (frame1), view->titlebar);
  gtk_box_pack_start (GTK_BOX (vbox), frame1, FALSE, FALSE, 0);
  gtk_box_pack_start (GTK_BOX (vbox), view->scroll_window, TRUE, TRUE, 0);

  gtk_container_add (GTK_CONTAINER (view), vbox);

  g_signal_connect (G_OBJECT (view), "focus-in-event",
                    G_CALLBACK (vochistory_listview_focus_in_event_cb), NULL);

  view->row_activated_cb = NULL;

  return;
}

GtkWidget *
vochistory_listview_new (void)
{
  VocHistoryListView *view;

  view = g_object_new (VOCHISTORY_TYPE_LISTVIEW, NULL);
  return GTK_WIDGET (view);
}

GtkListStore *
vochistory_listview_get_model (VocHistoryListView *view)
{
  if (view->liststore)
  {
    g_object_ref (view->liststore);
  }

  return view->liststore;
}

GtkWidget *
vochistory_listview_get_view (VocHistoryListView *view)
{
  if (view->liststore)
  {
    g_object_ref (view->treeview);
  }

  return view->treeview;
}

void
vochistory_listview_set_row_function (VocHistoryListView *view,
                                      VocHistoryListViewRowCallback cb_func)
{
  view->row_activated_cb = cb_func;

  return;
}

void
vochistory_listview_update (VocHistoryListView *view)
{
  GtkTreePath *path = NULL;

  g_print ("%s() entering\n", __FUNCTION__);
  path = gtk_tree_path_new_first ();
  gtk_tree_view_set_cursor (GTK_TREE_VIEW (view->treeview), path, NULL, TRUE);
  gtk_tree_path_free (path);
  g_print ("%s() leaving\n", __FUNCTION__);

  return;
}

/* 
vi:ts=2:nowrap:ai:expandtab 
*/

