/* 	libchenabler - Application of the call history service
 *
 *	Authors: JIANG Dan <dan.jiang@orange-ftgroup.com> 
 *	
 *	This software and associated documentation files (the "Software") 
 *	are copyright (C) 2005 LiPS Linux Phone Standards Forum [FranceTelecom] 
 *	All Rights Reserved. 
 *
 *	A copyright license is hereby granted for redistribution and use of 
 *	the Software in source and binary forms, with or without modification, 
 *	provided that the following conditions are met: 
 *	- Redistributions of source code must retain the above copyright notice, 
 *	this copyright license and the following disclaimer. 
 * - Redistributions in binary form must reproduce the above copyright 
 *	notice, this copyright license and the following disclaimer in the 
 *	documentation and/or other materials provided with the distribution. 
 *	- Neither the name of LiPS  nor the names of its Members may be used 
 *	to endorse or promote products derived from the Software without 
 *	specific prior written permission. 
 *
 *	A patent license for any Necessary Claims owned by Members of LiPS Forum 
 *	to make, have made, use, import, offer to sell, lease and sell or otherwise 
 *	distribute any implementation compliant with the any specification adopted 
 *	by the LiPS Forumcan be obtained from the respective Members on reasonable 
 *	and non-discriminatory terms and conditions and under reciprocity, as 
 *	regulated in more detail in the Internal Policy of the LiPS Forum. 
 *
 *	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER, ITS MEMBERS AND CONTRIBUTORS 
 *	"AS IS", AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 *	THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
 *	AND NON-INFRINGEMENT ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER, 
 *	ITS MEMBERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *	SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 *	PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 *	OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 *	WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *	ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 *	POSSIBILITY OF SUCH DAMAGE. 
 */


#ifndef VOCHISTORY_LISTVIEW_H_
#define VOCHISTORY_LISTVIEW_H_

#include <gtk/gtk.h>
#include <vochtype.h>
#include <gpe/gpeskwindow.h>
#ifdef __cplusplus
extern "C"
{
#endif

  typedef enum
  {
    ROW_NUM = 0,
    COL_CID,
    COL_TYPE,
    COL_PNUM,
    COL_DATE,
    COL_DURATION,
    COL_SORT_BASE,
    NUM_COLS
  } VocHistoryListViewCols;

#define VOCHISTORY_TYPE_LISTVIEW                                                     (vochistory_listview_get_type ())
#define VOCHISTORY_LISTVIEW(obj)                                                     (G_TYPE_CHECK_INSTANCE_CAST ((obj), VOCHISTORY_TYPE_LISTVIEW, VocHistoryListView))
#define VOCHISTORY_LISTVIEW_CLASS(klass)                     (G_TYPE_CHECK_CLASS_CAST ((klass), VOCHISTORY_TYPE_LISTVIEW, VocHistoryListViewClass))
#define VOCHISTORY_IS_LISTVIEW(obj)                                  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VOCHISTORY_TYPE_LISTVIEW))
#define VOCHISTORY_IS_LISTVIEW_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), VOCHISTORY_TYPE_LISTVIEW))
#define VOCHISTORY_LISTVIEW_GET_CLASS(obj)           (G_TYPE_INSTANCE_GET_CLASS ((obj), VOCHISTORY_TYPE_LISTVIEW, VocHistoryListViewClass))

  typedef struct _VocHistoryListView VocHistoryListView;
  typedef struct _VocHistoryListViewClass VocHistoryListViewClass;

  typedef void (*VocHistoryListViewRowCallback) (VocHistoryListView *view,
                                                 const gchar *cidstr);

  struct _VocHistoryListView
  {
    GpeSKWindow window;

    GtkWidget *titlebar;

    GtkWidget *scroll_window;

    GtkWidget *treeview;

    GtkListStore *liststore;

    VocHistoryListViewRowCallback row_activated_cb;
  };

  struct _VocHistoryListViewClass
  {
    GpeSKWindowClass parent_class;
  };

  GType vochistory_listview_get_type (void) G_GNUC_CONST;
  GtkWidget *vochistory_listview_new (void);
  GtkListStore *vochistory_listview_get_model (VocHistoryListView *view);
  GtkWidget *vochistory_listview_get_view (VocHistoryListView *view);

  void vochistory_listview_set_row_function (VocHistoryListView *view,
                                             VocHistoryListViewRowCallback
                                             cb_func);
  void vochistory_listview_update (VocHistoryListView *view);

  gboolean vochistory_listview_load_data (VocHistoryListView *view,
                                          voch_sid_t sid,
                                          voch_call_type_t datatype);
  gboolean vochistory_listview_delete_current (VocHistoryListView *view,
                                               voch_sid_t sid);
#ifdef __cplusplus
}
#endif

#endif                          /* VOCHISTORY_LISTVIEW_H_ */

/* 
vi:ts=2:nowrap:ai:expandtab 
*/

